==> heteroscalapack-1.0.2-BETA.tar.gz: heteroscalapack-1.0.2-BETA/include/hscalapackpmodels.h <==

/*******************************************************************
*                                                                  *
*                 Heterogeneous ScaLAPACK Performance models       *
*                         (INTERNAL)                               *
*                 ==========================================       *
*                                                                  *
*  Copyright (c) 2006   School of Computer Science and Informatics *
*                              University College Dublin.          *
*                                                                  *
*  All rights reserved. We assume no responsibility for the use    *
*  or reliability of our software.                                 *
*                                                                  *
********************************************************************/

#ifndef __HMPI_SCALAPACK_PMODELS_INCLUDE_HH
#define __HMPI_SCALAPACK_PMODELS_INCLUDE_HH

extern        HMPI_Model              MPC_NetType_pcgesv;
#define       hscal_model_pcgesv      (&MPC_NetType_pcgesv)

extern        HMPI_Model              MPC_NetType_pdgesv;
#define       hscal_model_pdgesv      (&MPC_NetType_pdgesv)

extern        HMPI_Model              MPC_NetType_psgesv;
#define       hscal_model_psgesv      (&MPC_NetType_psgesv)

extern        HMPI_Model              MPC_NetType_pzgesv;
#define       hscal_model_pzgesv      (&MPC_NetType_pzgesv)

extern        HMPI_Model              MPC_NetType_pcgetrf;
#define       hscal_model_pcgetrf      (&MPC_NetType_pcgetrf)

extern        HMPI_Model              MPC_NetType_pdgetrf;
#define       hscal_model_pdgetrf      (&MPC_NetType_pdgetrf)

extern        HMPI_Model              MPC_NetType_psgetrf;
#define       hscal_model_psgetrf      (&MPC_NetType_psgetrf)

extern        HMPI_Model              MPC_NetType_pzgetrf;
#define       hscal_model_pzgetrf      (&MPC_NetType_pzgetrf)

extern        HMPI_Model              MPC_NetType_pcgetrs;
#define       hscal_model_pcgetrs      (&MPC_NetType_pcgetrs)

extern        HMPI_Model              MPC_NetType_pdgetrs;
#define       hscal_model_pdgetrs      (&MPC_NetType_pdgetrs)

extern        HMPI_Model              MPC_NetType_psgetrs;
#define       hscal_model_psgetrs      (&MPC_NetType_psgetrs)

extern        HMPI_Model              MPC_NetType_pzgetrs;
#define       hscal_model_pzgetrs      (&MPC_NetType_pzgetrs)

extern        HMPI_Model              MPC_NetType_pcposv;
#define       hscal_model_pcposv      (&MPC_NetType_pcposv)

extern        HMPI_Model              MPC_NetType_pdposv;
#define       hscal_model_pdposv      (&MPC_NetType_pdposv)

extern        HMPI_Model              MPC_NetType_psposv;
#define       hscal_model_psposv      (&MPC_NetType_psposv)

extern        HMPI_Model              MPC_NetType_pzposv;
#define       hscal_model_pzposv      (&MPC_NetType_pzposv)

extern        HMPI_Model              MPC_NetType_pcpotrf;
#define       hscal_model_pcpotrf     (&MPC_NetType_pcpotrf)

extern        HMPI_Model              MPC_NetType_pdpotrf;
#define       hscal_model_pdpotrf     (&MPC_NetType_pdpotrf)

extern        HMPI_Model              MPC_NetType_pspotrf;
#define       hscal_model_pspotrf     (&MPC_NetType_pspotrf)

extern        HMPI_Model              MPC_NetType_pzpotrf;
#define       hscal_model_pzpotrf     (&MPC_NetType_pzpotrf)

extern        HMPI_Model              MPC_NetType_pcpotrs;
#define       hscal_model_pcpotrs     (&MPC_NetType_pcpotrs)

extern        HMPI_Model              MPC_NetType_pdpotrs;
#define       hscal_model_pdpotrs     (&MPC_NetType_pdpotrs)

extern        HMPI_Model              MPC_NetType_pspotrs;
#define       hscal_model_pspotrs     (&MPC_NetType_pspotrs)

extern        HMPI_Model              MPC_NetType_pzpotrs;
#define       hscal_model_pzpotrs     (&MPC_NetType_pzpotrs)

extern        HMPI_Model              MPC_NetType_pcdbsv;
#define       hscal_model_pcdbsv      (&MPC_NetType_pcdbsv)

extern        HMPI_Model              MPC_NetType_pddbsv;
#define       hscal_model_pddbsv      (&MPC_NetType_pddbsv)

extern        HMPI_Model              MPC_NetType_psdbsv;
#define       hscal_model_psdbsv      (&MPC_NetType_psdbsv)

extern        HMPI_Model              MPC_NetType_pzdbsv;
#define       hscal_model_pzdbsv      (&MPC_NetType_pzdbsv)

extern        HMPI_Model              MPC_NetType_pcdbtrf;
#define       hscal_model_pcdbtrf     (&MPC_NetType_pcdbtrf)

extern        HMPI_Model              MPC_NetType_pddbtrf;
#define       hscal_model_pddbtrf     (&MPC_NetType_pddbtrf)

extern        HMPI_Model              MPC_NetType_psdbtrf;
#define       hscal_model_psdbtrf     (&MPC_NetType_psdbtrf)

extern        HMPI_Model              MPC_NetType_pzdbtrf;
#define       hscal_model_pzdbtrf     (&MPC_NetType_pzdbtrf)

extern        HMPI_Model              MPC_NetType_pcdbtrs;
#define       hscal_model_pcdbtrs     (&MPC_NetType_pcdbtrs)

extern        HMPI_Model              MPC_NetType_pddbtrs;
#define       hscal_model_pddbtrs     (&MPC_NetType_pddbtrs)

extern        HMPI_Model              MPC_NetType_psdbtrs;
#define       hscal_model_psdbtrs     (&MPC_NetType_psdbtrs)

extern        HMPI_Model              MPC_NetType_pzdbtrs;
#define       hscal_model_pzdbtrs     (&MPC_NetType_pzdbtrs)

extern        HMPI_Model              MPC_NetType_pcgels;
#define       hscal_model_pcgels      (&MPC_NetType_pcgels)

extern        HMPI_Model              MPC_NetType_pdgels;
#define       hscal_model_pdgels      (&MPC_NetType_pdgels)

extern        HMPI_Model              MPC_NetType_psgels;
#define       hscal_model_psgels      (&MPC_NetType_psgels)

extern        HMPI_Model              MPC_NetType_pzgels;
#define       hscal_model_pzgels      (&MPC_NetType_pzgels)

extern        HMPI_Model              MPC_NetType_pcgelqf;
#define       hscal_model_pcgelqf     (&MPC_NetType_pcgelqf)

extern        HMPI_Model              MPC_NetType_pdgelqf;
#define       hscal_model_pdgelqf     (&MPC_NetType_pdgelqf)

extern        HMPI_Model              MPC_NetType_psgelqf;
#define       hscal_model_psgelqf     (&MPC_NetType_psgelqf)

extern        HMPI_Model              MPC_NetType_pzgelqf;
#define       hscal_model_pzgelqf     (&MPC_NetType_pzgelqf)

extern        HMPI_Model              MPC_NetType_pcgeqrf;
#define       hscal_model_pcgeqrf     (&MPC_NetType_pcgeqrf)

extern        HMPI_Model              MPC_NetType_pdgeqrf;
#define       hscal_model_pdgeqrf     (&MPC_NetType_pdgeqrf)

extern        HMPI_Model              MPC_NetType_psgeqrf;
#define       hscal_model_psgeqrf     (&MPC_NetType_psgeqrf)

extern        HMPI_Model              MPC_NetType_pzgeqrf;
#define       hscal_model_pzgeqrf     (&MPC_NetType_pzgeqrf)

#endif

==> heteroscalapack-1.0.4-BETA.tar.gz: heteroscalapack-1.0.4-BETA/include/hscalapackpmodels.h <==

/*******************************************************************
*                                                                  *
*                 Heterogeneous ScaLAPACK Performance models       *
*                         (INTERNAL)                               *
*                 ==========================================       *
*                                                                  *
*  Copyright (c) 2006   School of Computer Science and Informatics *
*                              University College Dublin.          *
*                                                                  *
*  All rights reserved. We assume no responsibility for the use    *
*  or reliability of our software.                                 *
*                                                                  *
********************************************************************/

#ifndef __HMPI_SCALAPACK_PMODELS_INCLUDE_HH
#define __HMPI_SCALAPACK_PMODELS_INCLUDE_HH

extern        HMPI_Model              MPC_NetType_pcgesv;
#define       hscal_model_pcgesv      (&MPC_NetType_pcgesv)

extern        HMPI_Model              MPC_NetType_pdgesv;
#define       hscal_model_pdgesv      (&MPC_NetType_pdgesv)

extern        HMPI_Model              MPC_NetType_psgesv;
#define       hscal_model_psgesv      (&MPC_NetType_psgesv)

extern        HMPI_Model              MPC_NetType_pzgesv;
#define       hscal_model_pzgesv      (&MPC_NetType_pzgesv)

extern        HMPI_Model              MPC_NetType_pcgetrf;
#define       hscal_model_pcgetrf      (&MPC_NetType_pcgetrf)

extern        HMPI_Model              MPC_NetType_pdgetrf;
#define       hscal_model_pdgetrf      (&MPC_NetType_pdgetrf)

extern        HMPI_Model              MPC_NetType_psgetrf;
#define       hscal_model_psgetrf      (&MPC_NetType_psgetrf)

extern        HMPI_Model              MPC_NetType_pzgetrf;
#define       hscal_model_pzgetrf      (&MPC_NetType_pzgetrf)

extern        HMPI_Model              MPC_NetType_pcgetrs;
#define       hscal_model_pcgetrs      (&MPC_NetType_pcgetrs)

extern        HMPI_Model              MPC_NetType_pdgetrs;
#define       hscal_model_pdgetrs      (&MPC_NetType_pdgetrs)

extern        HMPI_Model              MPC_NetType_psgetrs;
#define       hscal_model_psgetrs      (&MPC_NetType_psgetrs)

extern        HMPI_Model              MPC_NetType_pzgetrs;
#define       hscal_model_pzgetrs      (&MPC_NetType_pzgetrs)

extern        HMPI_Model              MPC_NetType_pcposv;
#define       hscal_model_pcposv      (&MPC_NetType_pcposv)

extern        HMPI_Model              MPC_NetType_pdposv;
#define       hscal_model_pdposv      (&MPC_NetType_pdposv)

extern        HMPI_Model              MPC_NetType_psposv;
#define       hscal_model_psposv      (&MPC_NetType_psposv)

extern        HMPI_Model              MPC_NetType_pzposv;
#define       hscal_model_pzposv      (&MPC_NetType_pzposv)

extern        HMPI_Model              MPC_NetType_pcpotrf;
#define       hscal_model_pcpotrf     (&MPC_NetType_pcpotrf)

extern        HMPI_Model              MPC_NetType_pdpotrf;
#define       hscal_model_pdpotrf     (&MPC_NetType_pdpotrf)

extern        HMPI_Model              MPC_NetType_pspotrf;
#define       hscal_model_pspotrf     (&MPC_NetType_pspotrf)

extern        HMPI_Model              MPC_NetType_pzpotrf;
#define       hscal_model_pzpotrf     (&MPC_NetType_pzpotrf)

extern        HMPI_Model              MPC_NetType_pcpotrs;
#define       hscal_model_pcpotrs     (&MPC_NetType_pcpotrs)

extern        HMPI_Model              MPC_NetType_pdpotrs;
#define       hscal_model_pdpotrs     (&MPC_NetType_pdpotrs)

extern        HMPI_Model              MPC_NetType_pspotrs;
#define       hscal_model_pspotrs     (&MPC_NetType_pspotrs)

extern        HMPI_Model              MPC_NetType_pzpotrs;
#define       hscal_model_pzpotrs     (&MPC_NetType_pzpotrs)

extern        HMPI_Model              MPC_NetType_pcdbsv;
#define       hscal_model_pcdbsv      (&MPC_NetType_pcdbsv)

extern        HMPI_Model              MPC_NetType_pddbsv;
#define       hscal_model_pddbsv      (&MPC_NetType_pddbsv)

extern        HMPI_Model              MPC_NetType_psdbsv;
#define       hscal_model_psdbsv      (&MPC_NetType_psdbsv)

extern        HMPI_Model              MPC_NetType_pzdbsv;
#define       hscal_model_pzdbsv      (&MPC_NetType_pzdbsv)

extern        HMPI_Model              MPC_NetType_pcdbtrf;
#define       hscal_model_pcdbtrf     (&MPC_NetType_pcdbtrf)

extern        HMPI_Model              MPC_NetType_pddbtrf;
#define       hscal_model_pddbtrf     (&MPC_NetType_pddbtrf)

extern        HMPI_Model              MPC_NetType_psdbtrf;
#define       hscal_model_psdbtrf     (&MPC_NetType_psdbtrf)

extern        HMPI_Model              MPC_NetType_pzdbtrf;
#define       hscal_model_pzdbtrf     (&MPC_NetType_pzdbtrf)

extern        HMPI_Model              MPC_NetType_pcdbtrs;
#define       hscal_model_pcdbtrs     (&MPC_NetType_pcdbtrs)

extern        HMPI_Model              MPC_NetType_pddbtrs;
#define       hscal_model_pddbtrs     (&MPC_NetType_pddbtrs)

extern        HMPI_Model              MPC_NetType_psdbtrs;
#define       hscal_model_psdbtrs     (&MPC_NetType_psdbtrs)

extern        HMPI_Model              MPC_NetType_pzdbtrs;
#define       hscal_model_pzdbtrs     (&MPC_NetType_pzdbtrs)

extern        HMPI_Model              MPC_NetType_pcgels_m_lt_n;
#define       hscal_model_pcgels_m_lt_n      (&MPC_NetType_pcgels_m_lt_n)

extern        HMPI_Model              MPC_NetType_pdgels_m_lt_n;
#define       hscal_model_pdgels_m_lt_n      (&MPC_NetType_pdgels_m_lt_n)

extern        HMPI_Model              MPC_NetType_psgels_m_lt_n;
#define       hscal_model_psgels_m_lt_n      (&MPC_NetType_psgels_m_lt_n)

extern        HMPI_Model              MPC_NetType_pzgels_m_lt_n;
#define       hscal_model_pzgels_m_lt_n      (&MPC_NetType_pzgels_m_lt_n)

extern        HMPI_Model              MPC_NetType_pcgels_m_ge_n;
#define       hscal_model_pcgels_m_ge_n      (&MPC_NetType_pcgels_m_ge_n)

extern        HMPI_Model              MPC_NetType_pdgels_m_ge_n;
#define       hscal_model_pdgels_m_ge_n      (&MPC_NetType_pdgels_m_ge_n)

extern        HMPI_Model              MPC_NetType_psgels_m_ge_n;
#define       hscal_model_psgels_m_ge_n      (&MPC_NetType_psgels_m_ge_n)

extern        HMPI_Model              MPC_NetType_pzgels_m_ge_n;
#define       hscal_model_pzgels_m_ge_n      (&MPC_NetType_pzgels_m_ge_n)

extern        HMPI_Model              MPC_NetType_pcgelqf;
#define       hscal_model_pcgelqf     (&MPC_NetType_pcgelqf)

extern        HMPI_Model              MPC_NetType_pdgelqf;
#define       hscal_model_pdgelqf     (&MPC_NetType_pdgelqf)

extern        HMPI_Model              MPC_NetType_psgelqf;
#define       hscal_model_psgelqf     (&MPC_NetType_psgelqf)

extern        HMPI_Model              MPC_NetType_pzgelqf;
#define       hscal_model_pzgelqf     (&MPC_NetType_pzgelqf)

extern        HMPI_Model              MPC_NetType_pcgeqrf;
#define       hscal_model_pcgeqrf     (&MPC_NetType_pcgeqrf)

extern        HMPI_Model              MPC_NetType_pdgeqrf;
#define       hscal_model_pdgeqrf     (&MPC_NetType_pdgeqrf)

extern        HMPI_Model              MPC_NetType_psgeqrf;
#define       hscal_model_psgeqrf     (&MPC_NetType_psgeqrf)

extern        HMPI_Model              MPC_NetType_pzgeqrf;
#define       hscal_model_pzgeqrf     (&MPC_NetType_pzgeqrf)

#endif
